import React, { useEffect, useState } from 'react';

import './index.css';

export function TodoLists() {
  const [todos, setTodos] = useState([]);
  const [newTodo, setNewTodo] = useState('');
  const [editingId, setEditingId] = useState(null);
  const [editingText, setEditingText] = useState('');

  useEffect(() => {
    const fetchTodos = async () => {
      const response = await fetch('http://localhost:3000/api/todo:list');
      const { data } = await response.json();
      if (Array.isArray(data)) setTodos(data);
    };
    fetchTodos();
  }, []);

  const handleAdd = async (e) => {
    e.preventDefault();
    if (newTodo.trim()) {
      const response = await fetch('http://localhost:3000/api/todo:create', {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify({ title: newTodo, completed: false }),
      });
      const newTodoItem = await response.json();
      setTodos([...todos, newTodoItem]);
      setNewTodo('');
    }
  };

  const handleDelete = async (id) => {
    await fetch(`http://localhost:3000/api/todo:destroy?filterByTk=${id}`, { method: 'DELETE' });
    setTodos(todos.filter((todo) => todo.id !== id));
  };

  const handleEdit = (id, title) => {
    setEditingId(id);
    setEditingText(title);
  };

  const handleUpdate = async (id) => {
    await fetch(`http://localhost:3000/api/todo:update?filterByTk=${id}`, {
      method: 'PUT',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify({ title: editingText }),
    });
    setTodos(todos.map((todo) => (todo.id === id ? { ...todo, title: editingText } : todo)));
    setEditingId(null);
    setEditingText('');
  };

  const handleToggleComplete = async (id, currentStatus) => {
    const updatedStatus = !currentStatus;
    await fetch(`http://localhost:3000/api/todo:update?filterByTk=${id}`, {
      method: 'PUT',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify({ completed: updatedStatus }),
    });
    setTodos(todos.map((todo) => (todo.id === id ? { ...todo, completed: updatedStatus } : todo)));
  };

  return (
    <div className="todoapp stack-large">
      <h1>TodoMatic</h1>
      <form onSubmit={handleAdd}>
        <h2 className="label-wrapper">
          <label htmlFor="new-todo-input" className="label__lg">
            What needs to be done?
          </label>
        </h2>
        <input
          type="text"
          id="new-todo-input"
          className="input input__lg"
          autoComplete="off"
          value={newTodo}
          onChange={(e) => setNewTodo(e.target.value)}
        />
        <button type="submit" className="btn btn__primary btn__lg">
          Add
        </button>
      </form>
      <h2 id="list-heading">{todos.length} tasks remaining</h2>
      <ul role="list" className="todo-list stack-large stack-exception" aria-labelledby="list-heading">
        {todos.map((todo) => (
          <li key={todo.id} className="todo stack-small">
            <div className="c-cb">
              <input
                id={`todo-${todo.id}`}
                type="checkbox"
                checked={todo.completed}
                onChange={() => handleToggleComplete(todo.id, todo.completed)}
              />
              {editingId === todo.id ? (
                <input type="text" value={editingText} onChange={(e) => setEditingText(e.target.value)} />
              ) : (
                <label className="todo-label" htmlFor={`todo-${todo.id}`}>
                  {todo.title}
                </label>
              )}
            </div>
            <div className="btn-group">
              {editingId === todo.id ? (
                <button type="button" className="btn" onClick={() => handleUpdate(todo.id)}>
                  Save
                </button>
              ) : (
                <button type="button" className="btn" onClick={() => handleEdit(todo.id, todo.title)}>
                  Edit
                </button>
              )}
              <button type="button" className="btn btn__danger" onClick={() => handleDelete(todo.id)}>
                Delete
              </button>
            </div>
          </li>
        ))}
      </ul>
    </div>
  );
}
